%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Стилевой файл для журнала Вестник ОИВТ
% (с) Кадатский М.А., Левашов П.Р., ОИВТ РАН, 2018
% Версия 1.05
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Changelog

%1.01
%Изменение регистра команды \ack Благодарности --> БЛАГОДАРНОСТИ
%Подключён пакет textcomp

%1.02
%Подключён пакет cmap

%1.03
%Подключен пакет hyperref для гиперссылок на литературу и формулы

%1.04
%Стилевой файл revtex4 заменен на revtex4-2 для совместимости с MiKTeX

%1.05
%Исправлена загрузка класса revtex4-2 для совместимости с MiKTeX. Величины стандартных отступов приведены к значениям как в revtex4

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}[1994/01/01]
\ProvidesClass{vestnik}[2022/12/21 v1.05]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{revtex4-2}}
\ProcessOptions
%\LoadClass{article}
\usepackage{cmap}
\LoadClass[a4paper,aps,pra,twocolumn,floatfix,10pt,twoside]{revtex4-2}
\usepackage{calc}
\usepackage{amssymb}
\usepackage{amsmath}
\usepackage{amsfonts}
\usepackage{amsbsy}
\usepackage{amsgen}
\usepackage{textcomp}
\usepackage{textcase}

\usepackage[T2A, T1]{fontenc}
\usepackage[utf8]{inputenc}
\usepackage[english,russian]{babel}
\usepackage{graphicx}
\usepackage{tabularx}
\usepackage{setspace}
\usepackage{fancyhdr}
\usepackage{indentfirst}
\usepackage{calc}

\usepackage[a4paper,left=12mm,right=12mm,top=10mm,bottom=10mm,includeheadfoot,nomarginpar,twocolumn,headheight=5mm]{geometry}


\setlength{\parindent}{0.73cm}
\setlength\topsep{0pt}

% This gets rid of extra vertical spacing in the center environment
\let\oldcenter\center
\let\oldendcenter\endcenter
\renewenvironment{center}{%
	\setlength\topsep{-2pt}
  \oldcenter
}{%
	\setlength\topsep{0pt}
  \oldendcenter
}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Bibliography redefinitions 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcounter{tmp}


\renewenvironment{thebibliography}[1]%
{\begin{list}{\arabic{tmp}.}{%
\usecounter{tmp}%
%\noindent\centering\rule{0.4\columnwidth}{0.4pt}%
%\vspace{3pt}%
\setlength{\rightmargin}{0pt}%
\settowidth{\labelwidth}{\@biblabel{#1}}%
%\settowidth{\labelsep}{\ \ }%
\setlength{\leftmargin}{\labelwidth+\labelsep}%
%\setlength{\topsep}{50pt}%
\setlength{\parsep}{0pt}%
\setlength{\itemsep}{0pt}%
\item[]}}%
{\end{list}}




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Enumerate redefinition
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\renewcommand{\@listI}{%
\setlength{\rightmargin}{0pt}%
\setlength{\labelwidth}{9pt}%
\settowidth{\labelsep}{\ \,}%
\setlength{\leftmargin}{\labelwidth+\labelsep}%
\setlength{\topsep}{0pt}%
\setlength{\parsep}{0pt}%
\setlength{\partopsep}{0pt}%
\setlength{\itemsep}{0pt}}

\renewcommand{\@listii}{%
\setlength{\rightmargin}{0pt}%
\setlength{\labelwidth}{9pt}%
\settowidth{\labelsep}{\ \,}%
\setlength{\leftmargin}{4pt+\labelwidth+\labelsep}%
\setlength{\topsep}{0pt}%
\setlength{\parsep}{0pt}%
\setlength{\partopsep}{0pt}%
\setlength{\itemsep}{0pt}}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Special commands for proceedings
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\articledoiText{\texttt{https://doi.org/xx.xxx/x.xxxxxxx}}

\def\articletitleText{}
\newcommand\articletitle[1]{\makecaptions\def\articletitleText{#1}}
\newcommand\articletitleHere{{\centering\noindent\Large\textbf{\nobabel{\articletitleText}}\par}}

\def\articleabstractText{}
\newcommand\articleabstract[1]{\def\articleabstractText{#1}}
\newcommand\articleabstractHere{\vspace{9pt}\noindent\small\textbf{Аннотация.\,\,\,}\articleabstractText{ }\articledoiText\par\vspace{12pt}}

\newcommand\articleauthor[1]{\vspace{9pt}\noindent{\textbf{\nobabel{#1}}}\par}
\newcommand\articleaffil[1]{\noindent{\nobabel{#1}}\par}
\newcommand\articleemail[1]{\vspace{6pt}\noindent{E-mail: \textsl{\tt#1}\relax}\par}
\newcommand\articledate[1]{\vspace{6pt}\noindent{\nobabel{#1}}\par}
\newcommand\articledoi[1]{\def\articledoiText{\texttt{#1}}}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Шапка
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\makecaptions}{\def\figurename{Рисунок}}



\newenvironment{articlehead}{\thispagestyle{firststyle}\onecolumngrid\articletitleHere\begin{center}\begin{minipage}{0.78\textwidth}\begin{center}}{\end{center} \articleabstractHere\end{minipage}\end{center}\twocolumngrid}

%
%\end{flushleft}
%\setlength{\extrarowheight}{3pt}

\long\def\@makecaption#1#2{%
  \par
  \vskip\abovecaptionskip
  \begingroup
   \small\rmfamily
   \sbox\@tempboxa{%
    \let\\\heading@cr
    \textbf{#1.} #2%
   }%
   \@ifdim{\wd\@tempboxa >\hsize}{%
    \begingroup
     \samepage
     \flushing
     \let\footnote\@footnotemark@gobble
     \textbf{#1.} #2\par
    \endgroup
   }{%
     \global \@minipagefalse
     \hb@xt@\hsize{\hfil\unhbox\@tempboxa\hfil}%
   }%
  \endgroup
  \vskip\belowcaptionskip
}%

%\renewcommand{\figurename}{Рис.~\arabic{figure}. }
\renewcommand{\thetable}{\arabic{table}}

\pagestyle{plain}
%\renewcommand*\captionlabeldelim{.}





%ENVIRONMENT: indented
\newenvironment{indented}{\begin{indented}}{\end{indented}}
\newenvironment{varindent}[1]{\begin{varindent}{#1}}{\end{varindent}}
%
\def\indented{\list{}{\itemsep=0\p@\labelsep=0\p@\itemindent=0\p@
   \labelwidth=0\p@\leftmargin=\mathindent\topsep=0\p@\partopsep=0\p@
   \parsep=0\p@\listparindent=15\p@}\footnotesize\rm}
\let\endindented=\endlist 
\def\varindent#1{\setlength{\varind}{#1}%
   \list{}{\itemsep=0\p@\labelsep=0\p@\itemindent=0\p@
   \labelwidth=0\p@\leftmargin=\varind\topsep=0\p@\partopsep=0\p@
   \parsep=0\p@\listparindent=15\p@}\footnotesize\rm}
\let\endvarindent=\endlist 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Journals
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\vestnikOIVT}{{\itshape\selectfont Вестник ОИВТ РАН}}
\newcommand{\BibTeX}{{\rm B\kern-.05em{\sc i\kern-.025em b}\kern-.08em
    T\kern-.1667em\lower.7ex\hbox{E}\kern-.125emX}}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fonts
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\DeclareOldFontCommand{\tt}{\normalfont\ttfamily}{\mathtt}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Tables
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\lineup{\def\0{\hbox{\phantom{0}}}%
    \def\m{\hbox{$\phantom{-}$}}%
    \def\-{\llap{$-$}}}

\newcommand{\Table}[1]{\begin{table}[t]
  \caption{#1}
	\begin{center}
  \lineup
  \begin{tabular}{l*{15}{l}}}
\def\endTable{\end{tabular}\end{center}\end{table}}
\let\endtab=\endTable
%
\newcommand{\fulltable}[1]{\begin{table}
  \caption{#1}
  \lineup
  \begin{tabular*}{\textwidth}{@{}l*{15}{@{\extracolsep{0pt plus 12pt}}l}}}
\def\endfulltable{\end{tabular*}\end{table}}


\newcommand{\boldarrayrulewidth}{1\p@} 
% Width of bold rule in tabular environment.

\def\bhline{\noalign{\ifnum0=`}\fi\hrule \@height  
\boldarrayrulewidth \futurelet \@tempa\@xhline}

\def\@xhline{\ifx\@tempa\hline\vskip \doublerulesep\fi
      \ifnum0=`{\fi}}

% Rules for tables with extra space around
%
\newcommand{\br}{\ms\bhline\ms}
\newcommand{\mr}{\ms\hline\ms}
%
\newcommand{\centre}[2]{\multispan{#1}{\hfill #2\hfill}}
\newcommand{\crule}[1]{\multispan{#1}{\hspace*{\tabcolsep}\hrulefill
  \hspace*{\tabcolsep}}}
\newcommand{\fcrule}[1]{\ifnum\thetabtype=1\multispan{#1}{\hrulefill
  \hspace*{\tabcolsep}}\else\multispan{#1}{\hrulefill}\fi}
%
% Extra spaces for tables and displayed equations
%
\newcommand{\ms}{\noalign{\vspace{3\p@ plus2\p@ minus1\p@}}}
\newcommand{\bs}{\noalign{\vspace{6\p@ plus2\p@ minus2\p@}}}
\newcommand{\ns}{\noalign{\vspace{-3\p@ plus-1\p@ minus-1\p@}}}
\newcommand{\es}{\noalign{\vspace{6\p@ plus2\p@ minus2\p@}}\displaystyle}%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Sections
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Acknowledgments (no heading if letter)
% Usage \ack for Acknowledgments, \ackn for Acknowledgement
\def\ack{\section*{БЛАГОДАРНОСТИ}}
\def\ackn{\section*{БЛАГОДАРНОСТИ}}
%SECTION DEFINITIONS

\def\p@subsection{}


\setcounter{secnumdepth}{3}
%\newcounter {section}
%\newcounter {subsection}[section]
%\newcounter {subsubsection}[subsection]
%\newcounter {paragraph}[subsubsection]
%\newcounter {subparagraph}[paragraph]
\renewcommand \thesection {\arabic{section}}
\renewcommand\thesubsection   {\thesection.\arabic{subsection}}
\renewcommand\thesubsubsection{\thesubsection .\arabic{subsubsection}}
\renewcommand\theparagraph    {\thesubsubsection.\arabic{paragraph}}
\renewcommand\thesubparagraph {\theparagraph.\arabic{subparagraph}}
%\nosections
\def\nosections{\vspace{30\p@ plus12\p@ minus12\p@}
    \noindent\ignorespaces}
		
\renewcommand\section{\@startsection {section}{1}{\z@}%
                   {-3.25ex\@plus -1ex \@minus -.2ex}%
                   {3pt}%
                   {\reset@font\normalsize\bfseries\raggedright}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                   {-3.25ex\@plus -1ex \@minus -.2ex}%
                   {1sp}%
                   {\reset@font\normalsize\itshape\raggedright}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     {-1em \@plus .2em}%
                                     {\reset@font\normalsize\itshape}}	
																																		
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ПРИЛОЖЕНИЕ
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%																																	
																																		
\newcommand\appendixlone[1]{
\def\appendixname{ПРИЛОЖЕНИЕ}
\def\appendixextraname{#1}
\appendix
\def\appendixname{ПРИЛОЖЕНИЕ}
\setcounter{section}{0}
\setcounter{subsection}{0}
\setcounter{subsubsection}{0}
\setcounter{equation}{0}
\setcounter{figure}{0}
\setcounter{table}{0}
\def\thesubsection{A\arabic{subsection}}
\def\theequation{A\arabic{equation}} 
\def\thetable{A\arabic{table}}
\def\thefigure{A\arabic{figure}}
\ifx\appendixextraname\empty\else\def\appendixextraname{: #1}\fi
\section*{\appendixname\appendixextraname}
}																																	
																																		
\let\Oldappendix\appendix
\renewcommand{\appendix}{
\def\appendixname{ПРИЛОЖЕНИЕ}
\Oldappendix
\setcounter{section}{0}
\setcounter{subsection}{0}
\setcounter{subsubsection}{0}
\setcounter{equation}{0}
\setcounter{figure}{0}
\setcounter{table}{0}
\def\thesubsection{\Alph{section}\arabic{subsection}}
\def\theequation{\Alph{section}\arabic{equation}} 
\def\thetable{\Alph{section}\arabic{table}}
\def\thefigure{\Alph{section}\arabic{figure}}
}																																	
																																																																		
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Новые команды
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\;{\protect\psemicolon}
\def\psemicolon{\relax\ifmmode\mskip\thickmuskip\else\kern .3333em\fi}
\def\pt(#1){({\it #1\/})}
		
\newcommand\nobabel[1]{\begin{hyphenrules}{nohyphenation}#1\end{hyphenrules}} %Отмена переноса по слогам
\renewcommand{\!}{\negthinspace}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Колонтитулы
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\articlevolumeN{1}
\def\articleyearN{2018}
\def\articleauthorstringN{}

\def\authorsting{}
\newcommand\articlevolume[1]{\def\articlevolumeN{#1}}
\newcommand\articleyear[1]{\def\articleyearN{#1}}
\newcommand\articleauthorstring[1]{\def\articleauthorstringN{#1}}

\fancypagestyle{firststyle}
{
\fancyhf{}
\renewcommand{\footrulewidth}{0pt} 
\renewcommand{\headrulewidth}{0pt} 
\fancyfoot[C]{\thepage}
}

\fancypagestyle{plain}
{
\fancyhf{}
\fancyfoot[C]{\thepage}
\fancyhead[L]{\fontsize{9pt}{10pt}\selectfont \articleauthorstringN}
\fancyhead[LO]{}
\fancyhead[RO]{\fontsize{9pt}{10pt}\selectfont\vestnikOIVT{}~\textbf{\articlevolumeN}~(\articleyearN)}
\renewcommand{\headrulewidth}{0.5pt}
%\fancyhf{}
}

\pagestyle{plain}

 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Рисунки
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Формулы
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\Tr}{\mathop{\mathrm{Tr}}\nolimits}
\newcommand{\tr}{\mathop{\mathrm{tr}}\nolimits}
\newcommand{\Or}{\mathord{\mathrm{O}}} %changed from \mathop 20/1/95
\newcommand{\lshad}{[\![}
\newcommand{\rshad}{]\!]}
\newcommand{\tdot}[1]{\stackrel{\dots}{#1}}

\newcommand{\e}{\mathrm{e}}
\newcommand{\rme}{\mathrm{e}}
\newcommand{\rmi}{\mathrm{i}}
\newcommand{\rmd}{\mathrm{d}}

\newcommand{\frm}[1]{\mathop{\mathrm{#1}}}
\newcommand{\fl}{}
\setlength{\arraycolsep}{1pt}

\def\cases#1{%
     \left\{\,\vcenter{\def\\{\cr}\normalbaselines\openup1\jot\m@th%
     \ialign{\strut$\displaystyle{##}\hfil$&\quad
     \rm##\hfil\crcr#1\crcr}}\right.}%
		
% Bold lower case Greek letters
\DeclareMathAlphabet{\bi}{OML}{cmm}{b}{it}
%
\newcommand{\balpha}{\boldsymbol{\alpha}}
\newcommand{\bbeta}{\boldsymbol{\beta}}
\newcommand{\bgamma}{\boldsymbol{\gamma}}
\newcommand{\bdelta}{\boldsymbol{\delta}}
\newcommand{\bepsilon}{\boldsymbol{\epsilon}}
\newcommand{\bzeta}{\boldsymbol{\zeta}}
\newcommand{\bfeta}{\boldsymbol{\eta}}
\newcommand{\btheta}{\boldsymbol{\theta}}
\newcommand{\biota}{\boldsymbol{\iota}}
\newcommand{\bkappa}{\boldsymbol{\kappa}}
\newcommand{\blambda}{\boldsymbol{\lambda}}
\newcommand{\bmu}{\boldsymbol{\mu}}
\newcommand{\bnu}{\boldsymbol{\nu}}
\newcommand{\bxi}{\boldsymbol{\xi}}
\newcommand{\bpi}{\boldsymbol{\pi}}
\newcommand{\brho}{\boldsymbol{\rho}}
\newcommand{\bsigma}{\boldsymbol{\sigma}}
\newcommand{\btau}{\boldsymbol{\tau}}
\newcommand{\bupsilon}{\boldsymbol{\upsilon}}
\newcommand{\bphi}{\boldsymbol{\phi}}
\newcommand{\bchi}{\boldsymbol{\chi}}
\newcommand{\bpsi}{\boldsymbol{\psi}}
\newcommand{\bomega}{\boldsymbol{\omega}}
\newcommand{\bvarepsilon}{\boldsymbol{\varepsilon}}
\newcommand{\bvartheta}{\boldsymbol{\vartheta}}
\newcommand{\bvaromega}{\boldsymbol{\varomega}}
\newcommand{\bvarrho}{\boldsymbol{\varrho}}
\newcommand{\bvarzeta}{\boldsymbol{\varsigma}}  %NB really sigma
\newcommand{\bvarsigma}{\boldsymbol{\varsigma}}
\newcommand{\bvarphi}{\boldsymbol{\varphi}}
%
% Bold upright capital Greek letters
%
\newcommand{\bGamma}{\boldsymbol{\Gamma}}
\newcommand{\bDelta}{\boldsymbol{\Delta}}
\newcommand{\bTheta}{\boldsymbol{\Theta}}
\newcommand{\bLambda}{\boldsymbol{\Lambda}}
\newcommand{\bXi}{\boldsymbol{\Xi}}
\newcommand{\bPi}{\boldsymbol{\Pi}}
\newcommand{\bSigma}{\boldsymbol{\Sigma}}
\newcommand{\bUpsilon}{\boldsymbol{\Upsilon}}
\newcommand{\bPhi}{\boldsymbol{\Phi}}
\newcommand{\bPsi}{\boldsymbol{\Psi}}
\newcommand{\bOmega}{\boldsymbol{\Omega}}
%
% Bold versions of miscellaneous symbols
%
\newcommand{\bpartial}{\boldsymbol{\partial}}
\renewcommand{\bell}{\boldsymbol{\ell}}
\newcommand{\bimath}{\boldsymbol{\imath}}
\newcommand{\bjmath}{\boldsymbol{\jmath}}
\newcommand{\binfty}{\boldsymbol{\infty}}
\newcommand{\bnabla}{\boldsymbol{\nabla}}
\newcommand{\bdot}{\boldsymbol{\cdot}}
%
% Symbols for caption
%
\newcommand{\opensquare}{\mbox{$\square$}}
\newcommand{\opentriangle}{\mbox{$\vartriangle$}}
\newcommand{\opentriangledown}{\mbox{$\triangledown$}}
\newcommand{\opendiamond}{\mbox{$\lozenge$}}
\newcommand{\fullsquare}{\mbox{$\blacksquare$}}
\newcommand{\fulldiamond}{\mbox{$\blacklozenge$}}
\newcommand{\fullstar}{\mbox{$\bigstar$}}
\newcommand{\fulltriangle}{\mbox{$\blacktriangle$}}
\newcommand{\fulltriangledown}{\mbox{$\blacktriangledown$}}	


\newcommand{\opencircle}{\mbox{\Large$\circ\,$}}  % moved Large outside maths
%\newcommand{\opensquare}{\mbox{$\rlap{$\sqcap$}\sqcup$}}
%\newcommand{\opentriangle}{\mbox{$\triangle$}}
%\newcommand{\opentriangledown}{\mbox{$\bigtriangledown$}}
%\newcommand{\opendiamond}{\mbox{$\diamondsuit$}}
\newcommand{\fullcircle}{\mbox{{\Large$\bullet\,$}}} % moved Large outside maths
%\newcommand{\fullsquare}{\,\vrule height5pt depth0pt width5pt}
\newcommand{\dotted}{\protect\mbox{${\mathinner{\cdotp\cdotp\cdotp\cdotp\cdotp\cdotp}}$}}
\newcommand{\dashed}{\protect\mbox{-\; -\; -\; -}}
\newcommand{\broken}{\protect\mbox{-- -- --}}
\newcommand{\longbroken}{\protect\mbox{--- --- ---}}
\newcommand{\chain}{\protect\mbox{--- $\cdot$ ---}}
\newcommand{\dashddot}{\protect\mbox{--- $\cdot$ $\cdot$ ---}}
\newcommand{\full}{\protect\mbox{------}}	
